@@ -1,12 +1,12 @@
-AFDM <- function (base, type, ncp = 5, graph = TRUE,sup.var=NULL, ind.sup = NULL){
+AFDM <- function (base, type, ncp = 5, graph = TRUE,sup.var=NULL, ind.sup = NULL, axes=c(1,2)){
     resultats <- MFA(base=base, group = rep(1,ncol(base)), type=type, name.group = colnames(base), num.group.sup = sup.var, ind.sup = ind.sup, graph=FALSE, ncp = ncp)
     
     class(resultats) <- c("MFA", "list")
     if (graph){
-      if (any("n"%in%type)) plot(resultats,choix="ind")
-      if (any("c"%in%type)|any("s"%in%type)) plot(resultats,choix="var")
-      plot(resultats,choix="ind",invisible="quali")
-      plot(resultats,choix="group",title="Variables representation")
+      if (any("n"%in%type)) plot(resultats,choix="ind", axes=axes)
+      if (any("c"%in%type)|any("s"%in%type)) plot(resultats,choix="var",axes=axes)
+      plot(resultats,choix="ind",invisible="quali", axes=axes)
+      plot(resultats,choix="group",title="Variables representation",axes=axes)
     }
     resultats$ind <- list(coord = resultats$ind$coord, contrib = resultats$ind$contrib, cos2 = resultats$ind$cos2)
     res <- list(eig = resultats$eig, ind = resultats$ind, group = resultats$group)
