@@ -1,5 +1,4 @@
-HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE) 
-{
+HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE,axes=c(1,2)) {
     hdil <- function(H) {
         nbnivh <- length(H)
         dil <- H
@@ -9,9 +8,7 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
             for (i in 1:(nbnivh - 1)) {
                 h <- nbnivh - i
                 k <- nbnivh - i + 1
-                for (j in 1:length(H[[k]])) {
-                  a <- c(a, rep(H[[k]][j] * dil[[k]][j], H[[k]][j]))
-                }
+                for (j in 1:length(H[[k]])) a <- c(a, rep(H[[k]][j] * dil[[k]][j], H[[k]][j]))
                 dil[[h]] <- a
                 a <- NULL
             }
@@ -26,8 +23,7 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
                 for (j in 1:length(H[[i]])) {
                   nbvarh[[i]][j] <- 0
                   if (j == 1) {
-                    for (k in 1:H[[i]][1]) nbvarh[[i]][j] <- nbvarh[[i]][j] + 
-                      nbvarh[[i - 1]][k]
+                    for (k in 1:H[[i]][1]) nbvarh[[i]][j] <- nbvarh[[i]][j] + nbvarh[[i - 1]][k]
                   }
                   else {
                     a <- 0
@@ -35,8 +31,7 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
                     for (n in 1:(j - 1)) a <- a + H[[i]][n]
                     a <- a + 1
                     for (n in 1:j) b <- b + H[[i]][n]
-                    for (k in a:b) nbvarh[[i]][j] <- nbvarh[[i]][j] + 
-                      nbvarh[[i - 1]][k]
+                    for (k in a:b) nbvarh[[i]][j] <- nbvarh[[i]][j] +  nbvarh[[i - 1]][k]
                   }
                 }
             }
@@ -53,17 +48,23 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
         cw.partiel <- H
         cw.partiel[[1]] <- cw
         for (n in 2:nbnivh) {
-            niv2 = MFA(niv1$call$XTDC, group = Hinter[[n]], type = c(rep("c", 
-                length(Hinter[[n]]))), weight.col.mfa = cw, graph = FALSE)
+            niv2 = MFA(niv1$call$XTDC, group = Hinter[[n]], type = c(rep("c", length(Hinter[[n]]))), weight.col.mfa = cw, graph = FALSE)
             cw = niv2$call$col.w * cw
             cw.partiel[[n]] <- cw
         }
         return(cw.partiel)
     }
+    if (is.null(rownames(X))) rownames(X) = 1:nrow(X)
+    if (is.null(colnames(X))) colnames(X) = paste("V",1:ncol(X),sep="")
+    for (j in 1:ncol(X)) if (colnames(X)[j]=="") colnames(X)[j] = paste("V",j,sep="")
+    for (j in 1:nrow(X)) if (is.null(rownames(X)[j])) rownames(X)[j] = paste("row",j,sep="")
     poids <- hweight(X, H, type = type)
     nbind <- dim(X)[1]
     nbnivo <- length(H)
     res1 <- list()
+    for (j in 1:ncol(X)) {
+      if (is.numeric(X[,j])) X[,j] = scale(X[,j],scale=FALSE)
+    }
     niv1 = MFA(X, group = H[[1]], type = type, ncp = ncp, graph = FALSE)
     X <- niv1$call$XTDC
     Hq = H
@@ -73,9 +74,7 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
     ind.quali <- NULL
     nbgroup <- length(H[[1]])
     for (g in 1:nbgroup) {
-        if (type[g] == "n") 
-            ind.quali <- c(ind.quali, c((ind.var + 1):(ind.var + 
-                niv1$call$group.mod[g])))
+        if (type[g] == "n") ind.quali <- c(ind.quali, c((ind.var + 1):(ind.var + niv1$call$group.mod[g])))
         ind.var <- ind.var + niv1$call$group.mod[g]
     }
     for (h in 1:nbnivo) {
@@ -84,16 +83,13 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
         data.partiel <- vector(mode = "list", length = nbgroup)
         group.mod <- Xdes[[h]]
         for (g in 1:nbgroup) {
-            data.partiel[[g]] <- as.data.frame(matrix(0, nrow(X), 
-                ncol(X), byrow = TRUE, dimnames = dimnames(data)))
-            data.partiel[[g]][, (ind.col + 1):(ind.col + Xdes[[h]][g])] <- X[, 
-                (ind.col + 1):(ind.col + Xdes[[h]][g])]
+            data.partiel[[g]] <- as.data.frame(matrix(0, nrow(X), ncol(X), byrow = TRUE, dimnames = dimnames(data)))
+            data.partiel[[g]][, (ind.col + 1):(ind.col + Xdes[[h]][g])] <- X[,(ind.col + 1):(ind.col + Xdes[[h]][g])]
             ind.col <- ind.col + group.mod[g]
         }
         res1[[h]] <- data.partiel
     }
-    res.afmh <- PCA(X, col.w = poids[[nbnivo]], graph = FALSE, 
-        ncp = ncp, scale.unit = FALSE)
+    res.afmh <- PCA(X, col.w = poids[[nbnivo]], graph = FALSE, ncp = ncp, scale.unit = FALSE)
     dilat <- hdil(H)
     nb.v.p <- ncol(res.afmh$ind$coord)
     coord.group <- list()
@@ -104,34 +100,26 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
         group.mod <- Xdes[[h]]
         aux.mat <- matrix(0, nbgroup, nb.v.p)
         for (g in 1:nbgroup) {
-            aux.mat[g, ] <- apply(res[ind.col:(ind.col + group.mod[g] - 
-                1), ], 2, sum)
+            aux.mat[g, ] <- apply(res[ind.col:(ind.col + group.mod[g] - 1), ], 2, sum)
             ind.col <- ind.col + group.mod[g]
         }
         colnames(aux.mat) <- colnames(res.afmh$var$cor)
         name.aux <- paste("L", h, ".", sep = "")
-        rownames(aux.mat) <- paste(name.aux, "G", 1:nbgroup, 
-            sep = "")
+        rownames(aux.mat) <- paste(name.aux, "G", 1:nbgroup, sep = "")
         coord.group[[h]] <- aux.mat
     }
     part1 <- list()
-    if (!is.null(ind.quali)) 
-        part1.quali <- list()
+    if (!is.null(ind.quali)) part1.quali <- list()
 
     for (h in 1:nbnivo) {
         nbgroup <- length(H[[h]])
-        part2 <- array(0, dim = c(nrow(res.afmh$ind$coord), nb.v.p, 
-            nbgroup))
-        if (!is.null(ind.quali)) 
-            part2.quali <- array(0, dim = c(length(ind.quali), 
-                nb.v.p, nbgroup))
+        part2 <- array(0, dim = c(nrow(res.afmh$ind$coord), nb.v.p, nbgroup))
+        if (!is.null(ind.quali)) part2.quali <- array(0, dim = c(length(ind.quali), nb.v.p, nbgroup))
 
         for (g in 1:nbgroup) {
             formule <- matrix(0, dim(X)[1], nb.v.p)
-            formule <- (as.matrix(res1[[h]][[g]])) %*% diag(poids[[nbnivo]]) %*% 
-                t(X) %*% diag(rep((1/nbind), nbind))
-            formule <- formule %*% as.matrix(res.afmh$ind$coord) %*% 
-                diag(1/res.afmh$eig[1:nb.v.p, 1]) * dilat[[h]][g]
+            formule <- (as.matrix(res1[[h]][[g]])) %*% diag(poids[[nbnivo]]) %*% t(X) %*% diag(rep((1/nbind), nbind))
+            formule <- formule %*% as.matrix(res.afmh$ind$coord) %*% diag(1/res.afmh$eig[1:nb.v.p, 1]) * dilat[[h]][g]
             namecol <- paste("Dim", 1:nb.v.p, sep = "")
             formule <- matrix(formule, dim(formule)[1], dim(formule)[2])
             colnames(part2) <- namecol
@@ -151,17 +139,12 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
         }
     }
 
-    results <- list(eig = res.afmh$eig, group = coord.group, 
-        ind = res.afmh$ind, partial = part1)
+    results <- list(eig = res.afmh$eig, group = coord.group, ind = res.afmh$ind, partial = part1)
     if (!is.null(ind.quali) & length(ind.quali) < nrow(res.afmh$var$coord)) {
-        results$quanti.var$coord <- res.afmh$var$coord[-ind.quali, 
-            ]
-        results$quanti.var$cor <- res.afmh$var$cor[-ind.quali, 
-            ]
-        results$quanti.var$cos2 <- res.afmh$var$cos2[-ind.quali, 
-            ]
-        results$quanti.var$contrib <- res.afmh$var$contrib[-ind.quali, 
-            ]
+        results$quanti.var$coord <- res.afmh$var$coord[-ind.quali, ]
+        results$quanti.var$cor <- res.afmh$var$cor[-ind.quali,  ]
+        results$quanti.var$cos2 <- res.afmh$var$cos2[-ind.quali,  ]
+        results$quanti.var$contrib <- res.afmh$var$contrib[-ind.quali, ]
     }
     if (is.null(ind.quali)) {
         results$quanti.var$coord <- res.afmh$var$coord
@@ -174,21 +157,18 @@ HMFA<-function (X, H, type = rep("s", length(H[[1]])), ncp = 5, graph = TRUE)
         for (k in 1:length(ind.quali)) 
         if (sum(as.integer(X[,ind.quali[k]] > 0))<2) aux[k, ] <- res.afmh$ind$coord[X[,ind.quali[k]] > 0, ]
         else aux[k, ] <- apply(res.afmh$ind$coord[X[,ind.quali[k]] > 0, ], 2, mean)
-        dimnames(aux) <- dimnames(res.afmh$var$contrib[ind.quali, 
-            ])
+        dimnames(aux) <- dimnames(res.afmh$var$contrib[ind.quali, ])
         results$quali.var$coord <- aux
-        results$quali.var$contrib <- res.afmh$var$contrib[ind.quali, 
-            ]
+        results$quali.var$contrib <- res.afmh$var$contrib[ind.quali, ]
         results$quali.var$partial <- part1.quali
     }
     results$call$H <- H
-    if (!is.null(ind.quali)) 
-        results$call$Hq <- Xdes
+    if (!is.null(ind.quali)) results$call$Hq <- Xdes
     class(results) <- c("HMFA", "list")
     if (graph) {
-        plot.HMFA(results, choix = "ind")
-        plot.HMFA(results, choix = "var")
-        plot.HMFA(results, choix = "group")
+        plot.HMFA(results, choix = "ind",axes=axes)
+        plot.HMFA(results, choix = "var",axes=axes)
+        plot.HMFA(results, choix = "group",axes=axes)
     }
     return(results)
 }
